from setuptools import setup

setup(name = 'myAnimals',
        description = 'Distinguish mammals and birds',
        url = '',
        author = 'Saeed Mirshekari',
        author_email = 'saeed.mirshekari@gmail.com',
        license = 'MIT',
        packages = ['myAnimals'],
        zip_self = False)
